// Copyright 2011 Thomas Kamps anubis1@linux-ecke.de
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 3 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the7 implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

#ifndef LIGHTWEIGHT_H
#define LIGHTWEIGHT_H

#include <QWidget>
#include <QStackedLayout>
#include <QList>
#include <QMenu>

#include "bookmark.h"
#include "browsertab.h"

namespace Ui {
	class Lightweight;
}

class Lightweight : public QWidget {
	Q_OBJECT

	public:
		explicit Lightweight(QWidget *parent = 0);
		~Lightweight();

	protected:
		void closeEvent(QCloseEvent* e);

	private slots:
		void newTab(QString url="about:blank", bool hideUrlBar=false);

		void back();
		void forward();
		void stop();
		void reload();

		void search();

		void showTab(BrowserTab* tab);
		void closeTab(BrowserTab* tab);
		void openBookmark(QAction* ac);

		void addBookmark(QString title, QString url, QIcon icon);

		void switchFullscreen();
		void nextTab();
		void closeCurrentTab();

	private:
		QString hashFor(QString str);

		Ui::Lightweight *ui;
		QStackedLayout* tabs;
		QList<BrowserTab*>* tabList;

		QMenu* bookmarkMenu;
		QList<Bookmark*>* bookmarks;

		BrowserTab* currentTab;

		bool fullscreen;
};

#endif // LIGHTWEIGHT_H
